/*
 *  vector_3D.cpp
 *
 *  Author: M. Reza Mozaffari
 *  Physics Group, University of Qom
 *  Created on: Dec. 2020
 */

#include "vector_3D.h"

void print(V3D v)
{
    printf("(%.6f, %.6f, %.6f)\n", v.x, v.y, v.z);
}

V3D add(V3D v, V3D u)
{
    return {v.x + u.x, v.y + u.y, v.z + u.z};
}

V3D sub(V3D v, V3D u)
{
    return {v.x - u.x, v.y - u.y, v.z - u.z};
}

double dot(V3D v, V3D u)
{
    return v.x*u.x + v.y*u.y + v.z*u.z;
}

V3D cross(V3D v, V3D u)
{
    return {v.y*u.z - v.z*u.y, v.z*u.x - v.x*u.z, v.x*u.y - v.y*u.x};
}

V3D scale(V3D v, double alpha)
{
    return {alpha*v.x, alpha*v.y, alpha*v.z};
}

double norm(V3D v)
{
    return sqrt(v.x*v.x + v.y*v.y + v.z*v.z);
}

V3D hat(V3D v)
{
    double r {0.0};
    r = norm(v);
    return scale(v, 1./r);
}